Menu
====

MySmile provides two menu types:
  * Main menu --- like "home", "about", "contact", etc.
  * Additional dynamic menu --- internal links inside page for instance "readme", "instructions", etc.

+----------------------------+-------------+
| Name                       | Required    |
+============================+=============+
| Logo (Main Page) [#f1]_    | yes [#f2]_  |
+----------------------------+-------------+
| Menu 1, ..., Menu 5 [#f3]_ | no          |
+----------------------------+-------------+


.. rubric:: Footnotes

.. [#f1]  Click on Logo is always follow to the first page of the menu. Therefore changing menu order automatically changes the link for Logo.
.. [#f2] "Main page" is recommended page with slug name "index". 
.. [#f3] The optimal number of the main menu. 
